==> estateplat-common-1.2.3-20180316.075059-46-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxmJg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @version 1.0, 2018/3/13
 * @auther <a href="mailto:jiangganzhi@gtmap.cn" >jiangganhzi on 2018/3/13.</a>
 * @description 不动产收费项目结果（用于发票信息）
 */
@Table(name = "BDC_SFXM_JG")
public class BdcSfxmJg {
    @Id
    private String sfxmid;//收费项目ID

    private String sfxxid;//收费信息ID

    private String sfxmbm;//收费项目编码

    private String sfxmmc;//收费项目名称

    private String dw;//单位

    private int sl;//数量

    private String sfbz;//收费标准

    private double je;//金额

    private double jsbz;//计算标准

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmbm() {
        return sfxmbm;
    }

    public void setSfxmbm(String sfxmbm) {
        this.sfxmbm = sfxmbm;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public int getSl() {
        return sl;
    }

    public void setSl(int sl) {
        this.sl = sl;
    }

    public double getJe() {
        return je;
    }

    public void setJe(double je) {
        this.je = je;
    }

    public String getSfbz() { return sfbz; }

    public void setSfbz(String sfbz) { this.sfbz = sfbz;}

    public double getJsbz() { return jsbz; }

    public void setJsbz(double jsbz) { this.jsbz = jsbz; }
}

==> estateplat-common-1.2.4-20191105.011458-173-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxmJg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @version 1.0, 2018/3/13
 * @auther <a href="mailto:jiangganzhi@gtmap.cn" >jiangganhzi on 2018/3/13.</a>
 * @description 不动产收费项目结果（用于发票信息）
 */
@Table(name = "BDC_SFXM_JG")
public class BdcSfxmJg {
    @Id
    private String sfxmid;//收费项目ID

    private String sfxxid;//收费信息ID

    private String sfxmbm;//收费项目编码

    private String sfxmmc;//收费项目名称

    private String dw;//单位

    private int sl;//数量

    private String sfbz;//收费标准

    private double je;//金额

    private String dxje;//大写金额

    private double jsbz;//计算标准

    public String getSfxmid() {
        return sfxmid;
    }

    public void setSfxmid(String sfxmid) {
        this.sfxmid = sfxmid;
    }

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getSfxmbm() {
        return sfxmbm;
    }

    public void setSfxmbm(String sfxmbm) {
        this.sfxmbm = sfxmbm;
    }

    public String getSfxmmc() {
        return sfxmmc;
    }

    public void setSfxmmc(String sfxmmc) {
        this.sfxmmc = sfxmmc;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public int getSl() {
        return sl;
    }

    public void setSl(int sl) {
        this.sl = sl;
    }

    public double getJe() {
        return je;
    }

    public void setJe(double je) {
        this.je = je;
    }

    public String getSfbz() { return sfbz; }

    public void setSfbz(String sfbz) { this.sfbz = sfbz;}

    public String getDxje() {
        return dxje;
    }

    public void setDxje(String dxje) {
        this.dxje = dxje;
    }

    public double getJsbz() { return jsbz; }

    public void setJsbz(double jsbz) { this.jsbz = jsbz; }
}
